@@ -252,18 +252,12 @@ struct LogImpl
 };
 
 template<typename T> static Vc_ALWAYS_INLINE Vc_CONST Vector<T> log(VC_ALIGNED_PARAMETER(Vector<T>) x) {
-    typedef typename Vector<T>::Mask M;
-    typedef Const<T> C;
     return LogImpl<BaseE>::calc(x);
 }
 template<typename T> static Vc_ALWAYS_INLINE Vc_CONST Vector<T> log10(VC_ALIGNED_PARAMETER(Vector<T>) x) {
-    typedef typename Vector<T>::Mask M;
-    typedef Const<T> C;
     return LogImpl<Base10>::calc(x);
 }
 template<typename T> static Vc_ALWAYS_INLINE Vc_CONST Vector<T> log2(VC_ALIGNED_PARAMETER(Vector<T>) x) {
-    typedef typename Vector<T>::Mask M;
-    typedef Const<T> C;
     return LogImpl<Base2>::calc(x);
 }
 } // namespace Common
