@@ -102,8 +102,9 @@
 #undef VC_ALIGNED_PARAMETER
 #undef VC_OFFSETOF
 
-#if VC_GCC && !__OPTIMIZE__
+#ifdef Vc_POP_GCC_DIAGNOSTIC__
 #pragma GCC diagnostic pop
+#undef Vc_POP_GCC_DIAGNOSTIC__
 #endif
 
 #endif // VC_COMMON_UNDOMACROS_H
