@@ -26,10 +26,8 @@ using namespace Vc;
 
 template<typename Vec> void testSort()
 {
-    typedef typename Vec::EntryType EntryType;
     typedef typename Vec::IndexType IndexType;
 
-    typename Vec::Memory _a;
     const IndexType _ref(IndexesFromZero);
     Vec ref(_ref);
     Vec a;
@@ -40,26 +38,34 @@ template<typename Vec> void testSort()
     for (int perm = 0; perm < maxPerm; ++perm) {
         int rest = perm;
         for (int i = 0; i < Vec::Size; ++i) {
-            _a[i] = 0;
+            a[i] = 0;
             for (int j = 0; j < i; ++j) {
-                if (_a[i] == _a[j]) {
-                    ++_a[i];
+                if (a[i] == a[j]) {
+                    ++(a[i]);
                     j = -1;
                 }
             }
-            _a[i] += rest % (Vec::Size - i);
+            a[i] += rest % (Vec::Size - i);
             rest /= (Vec::Size - i);
             for (int j = 0; j < i; ++j) {
-                if (_a[i] == _a[j]) {
-                    ++_a[i];
+                if (a[i] == a[j]) {
+                    ++(a[i]);
                     j = -1;
                 }
             }
         }
-        a.load(_a);
         //std::cout << a << a.sorted() << std::endl;
         COMPARE(ref, a.sorted()) << ", a: " << a;
     }
+
+    for (int repetition = 0; repetition < 1000; ++repetition) {
+        Vec test = Vec::Random();
+        Vc::Memory<Vec, Vec::Size> reference;
+        reference.vector(0) = test;
+        std::sort(&reference[0], &reference[Vec::Size]);
+        ref = reference.vector(0);
+        COMPARE(ref, test.sorted());
+    }
 }
 
 template<typename T, typename Mem> struct Foo
@@ -102,8 +108,6 @@ template<typename V> void testForeachBit()
 {
     typedef typename V::EntryType T;
     typedef typename V::IndexType I;
-    typedef typename V::Mask M;
-    typedef typename I::Mask MI;
     const I indexes(IndexesFromZero);
     for_all_masks(V, mask) {
         V tmp = V::Zero();
@@ -134,7 +138,6 @@ template<typename V> void testForeachBit()
 
 template<typename V> void copySign()
 {
-    typedef typename V::EntryType T;
     V v(One);
     V positive(One);
     V negative = -positive;
